@@ -484,7 +484,11 @@ Returns the name of the file associated with the C<COP> C<c>
 Returns the line number in the source code associated with the C<COP> C<c>
 
 =for apidoc Am|AV *|CopFILEAV|const COP * c
-Returns the AV associated with the C<COP> C<c>
+Returns the AV associated with the C<COP> C<c>, creating it if necessary.
+
+=for apidoc Am|AV *|CopFILEAVn|const COP * c
+Returns the AV associated with the C<COP> C<c>, returning NULL if it
+doesn't already exist.
 
 =for apidoc Am|SV *|CopFILESV|const COP * c
 Returns the SV associated with the C<COP> C<c>
@@ -520,6 +524,7 @@ string C<p>, creating the package if necessary.
 */
 
 #ifdef USE_ITHREADS
+
 #  define CopFILE(c)		((c)->cop_file)
 #  define CopFILEGV(c)		(CopFILE(c) \
                                  ? gv_fetchfile(CopFILE(c)) : NULL)
@@ -533,13 +538,15 @@ string C<p>, creating the package if necessary.
                                  ? GvAV(gv_fetchfile(CopFILE(c))) : NULL)
 #  define CopFILEAVx(c)		(assert_(CopFILE(c)) \
                                    GvAV(gv_fetchfile(CopFILE(c))))
-
+#  define CopFILEAVn(c)         (cop_file_avn(c))
 #  define CopSTASH(c)           PL_stashpad[(c)->cop_stashoff]
 #  define CopSTASH_set(c,hv)	((c)->cop_stashoff = (hv)		\
                                     ? alloccopstash(hv)			\
                                     : 0)
 #  define CopFILE_free(c)	(PerlMemShared_free(CopFILE(c)),(CopFILE(c) = NULL))
-#else /* Above: no threads; Below yes threads */
+
+#else /* Above: yes threads; Below no threads */
+
 #  define CopFILEGV(c)		((c)->cop_filegv)
 #  define CopFILEGV_set(c,gv)	((c)->cop_filegv = (GV*)SvREFCNT_inc(gv))
 #  define CopFILE_set(c,pv)	CopFILEGV_set((c), gv_fetchfile(pv))
@@ -551,6 +558,7 @@ string C<p>, creating the package if necessary.
 #  else
 #    define CopFILEAVx(c)	(GvAV(CopFILEGV(c)))
 # endif
+#  define CopFILEAVn(c)         (CopFILEGV(c) ? GvAVn(CopFILEGV(c)) : NULL)
 #  define CopFILE(c)		(CopFILEGV(c) /* +2 for '_<' */         \
                                     ? GvNAME(CopFILEGV(c))+2 : NULL)
 #  define CopSTASH(c)		((c)->cop_stash)
@@ -1080,6 +1088,10 @@ struct context {
 #define CxFOREACH(c)	(   CxTYPE(cx) >= CXt_LOOP_ARY                  \
                          && CxTYPE(cx) <= CXt_LOOP_LIST)
 
+/* private flags for CXt_DEFER */
+#define CXp_FINALLY     0x20    /* `finally` block; semantically identical
+                                 * but matters for diagnostic messages */
+
 /* deprecated old name before real try/catch was added */
 #define CXp_TRYBLOCK    CXp_EVALBLOCK
 #define CxTRYBLOCK(c)   CxEVALBLOCK(c)
